@@ -237,7 +237,9 @@ def push_csv2tog(job_id: int, file_path: str, access_token: str):
     data_frame = pd.read_csv(file_path)
     dataset = []
     for _, row in tqdm(data_frame.iterrows(), total=len(data_frame)):
-        data = json.loads(row["data"])
+        alternatives = json.loads(row["alternatives"])
+        if isinstance(alternatives, list) and isinstance(alternatives[0], dict):
+            alternatives = [alternatives]
         dataset.append({
             "priority": 1,
             "data_source": "fsm",
@@ -245,7 +247,7 @@ def push_csv2tog(job_id: int, file_path: str, access_token: str):
             "data": {
                 "call_uuid": row["call_uuid"],
                 "conversation_uuid": row["conversation_uuid"],
-                "alternatives": data["alternatives"],
+                "alternatives": alternatives,
                 "audio_url": row["audio_url"],
                 "reftime": row["reftime"],
                 "prediction": row["prediction"],
